
# DO NOT EDIT THIS FILE -- AUTOGENERATED BY PANTS
# Target: llamazure/tools:llamazure.tools

from setuptools import setup

setup(**{
    'author': 'Daniel Goldman',
    'classifiers': [
        'Development Status :: 3 - Alpha',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
        'Programming Language :: Python :: 3.12',
        'Programming Language :: Python :: 3.13',
        'Topic :: Utilities',
    ],
    'description': 'A bundle of helpful tools for dealing with Azure',
    'entry_points': {
        'console_scripts': [
            'llamazure-migrate = llamazure.tools.migrate.__main__:migrate',
        ],
    },
    'install_requires': (
        'azure-identity<2.0.0,>=1.4.0',
        'click~=8.0',
        'llamazure.azrest~=0.3.0',
        'llamazure.rid~=0.1.0',
    ),
    'license': 'Round Robin 2.0.0',
    'long_description': """# llamazure.tools

A bundle of helpful tools for dealing with Azure

## llamazure.tools.migrate

Migrate some azure objects

### Usage

#### Migrate the Workspace of a Dashboard

```bash
pants run llamazure/tools/migrate/__main__.py -- dashboard --resource-id '/subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/test-dashboards/providers/Microsoft.Portal/dashboards/00000000-0000-0000-0000-000000000001' --replacements '{"/subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/test-dashboards/providers/Microsoft.OperationalInsights/workspaces/test-0":"/subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/test-dashboards/providers/Microsoft.OperationalInsights/workspaces/test-1"}' --backup-directory '/tmp/o'
```

#### Migrate the Workspace of a Workbook

```bash
pants run llamazure/tools/migrate/__main__.py -- workbook --resource-id '/subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/test-dashboards/providers/microsoft.insights/workbooks/00000000-0000-0000-0000-000000000001' --replacements '{"/subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/test-dashboards/providers/Microsoft.OperationalInsights/workspaces/test-0":"/subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/test-dashboards/providers/Microsoft.OperationalInsights/workspaces/test-1"}' --backup-directory '/tmp/o'
```""",
    'long_description_content_type': 'text/markdown',
    'name': 'llamazure.tools',
    'namespace_packages': (
    ),
    'package_data': {
    },
    'packages': (
        'llamazure.tools',
        'llamazure.tools.migrate',
        'llamazure.tools.migrate.applicationinsights.r.m.insights',
        'llamazure.tools.migrate.c.r.v1',
        'llamazure.tools.migrate.c.r.v3',
        'llamazure.tools.migrate.c.r.v5',
        'llamazure.tools.migrate.portal.r.m.portal',
    ),
    'python_requires': '>=3.9',
    'version': '0.2.0',
})
